from django.conf.urls import url
from django.views.decorators.csrf import csrf_exempt
from telegrambot import views
from django.contrib.auth.decorators import login_required


urlpatterns = [
    url(r'^webhook/(?P<token>[-_:a-zA-Z0-9]+)/$', csrf_exempt(views.WebhookView.as_view()), name='webhook'),
    url(r'^auth/(?P<bot>[-_a-zA-Z0-9]+)/$', login_required(views.AuthView.as_view()), name='auth')
]


# coding=utf-8
from factory import SubFactory, DjangoModelFactory 
from telegrambot.test.factories.user import UserWebFactory
from telegrambot.models import AuthToken

class AuthTokenFactory(DjangoModelFactory):
    user = SubFactory(UserWebFactory)
    
    class Meta:
        model = AuthToken


# coding=utf-8
from factory import DjangoModelFactory 
from telegrambot.models import Bot


class BotFactory(DjangoModelFactory):
    class Meta:
        model = Bot
    token = "174446943:AAEcMXep4Uc51sAkYcTJC7vEoLmmxwnQgcc"


# -*- coding: utf-8 -*-
# Generated by Django 1.9.1 on 2016-01-30 13:07
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('telegrambot', '0001_initial'),
    ]

    operations = [
        migrations.CreateModel(
            name='Bot',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('name', models.CharField(blank=True, max_length=200, null=True, verbose_name='Name')),
                ('token', models.CharField(db_index=True, max_length=100, verbose_name='Token')),
                ('ssl_certificate', models.FileField(blank=True, null=True, upload_to=b'telegrambot/ssl/', verbose_name='SSL certificate')),
                ('enabled', models.BooleanField(default=True, verbose_name='Enable')),
                ('created', models.DateTimeField(auto_now_add=True, verbose_name=b'Date Created')),
                ('modified', models.DateTimeField(auto_now=True, verbose_name='Date Modified')),
            ],
            options={
                'verbose_name': 'Bot',
                'verbose_name_plural': 'Bots',
            },
        ),
    ]



# -*- coding: utf-8 -*-
# Generated by Django 1.9.1 on 2016-02-02 18:03
from __future__ import unicode_literals

from django.conf import settings
from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
        ('telegrambot', '0002_bot'),
    ]

    operations = [
        migrations.CreateModel(
            name='AuthToken',
            fields=[
                ('key', models.CharField(max_length=40, primary_key=True, serialize=False)),
                ('created', models.DateTimeField(auto_now_add=True)),
                ('chat_api', models.OneToOneField(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, related_name='auth_token', to='telegrambot.Chat')),
                ('user', models.OneToOneField(on_delete=django.db.models.deletion.CASCADE, related_name='auth_token', to=settings.AUTH_USER_MODEL)),
            ],
            options={
                'verbose_name': 'Authentication Token',
                'verbose_name_plural': 'Authentications Tokens',
            },
        ),
        migrations.RemoveField(
            model_name='bot',
            name='name',
        ),
        migrations.AddField(
            model_name='bot',
            name='user_api',
            field=models.OneToOneField(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, related_name='bot', to='telegrambot.User', verbose_name='Bot User'),
        ),
    ]
